# smpl
Simplified plotting and fitting in python.

[![PyPI version][pypi image]][pypi link]    ![downloads](https://img.shields.io/pypi/dm/smpl.svg)

| [Stable][doc stable]        | [Unstable][doc test]           |
| ------------- |:-------------:|
| [![workflow][a s image]][a s link]      | [![test][a t image]][a t link]     |
| [![Coverage Status][c s i]][c s l] | [![Coverage Status][c t i]][c t l] |
| [![Codacy Badge][cc s c i]][cc s c l]      |[![Codacy Badge][cc c i]][cc c l] | 
| [![Codacy Badge][cc s q i]][cc s q l]    |[![Codacy Badge][cc q i]][cc q l] | 
| [![Documentation][rtd s i]][rtd s l] | [![Documentation][rtd t i]][rtd t l]  | 

## Documentation

-   <https://smpl.readthedocs.io/en/stable/>
-   <https://apn-pucky.github.io/smpl/index.html>

## Versions

### Stable

```sh
pip install smpl
```

Optional: --user or --upgrade

### Dev

```sh
pip install --index-url https://test.pypi.org/simple/ smpl
```

[doc stable]: https://apn-pucky.github.io/smpl/index.html
[doc test]: https://apn-pucky.github.io/smpl/test/index.html

[pypi image]: https://badge.fury.io/py/smpl.svg
[pypi link]: https://pypi.org/project/smpl/

[a s image]: https://github.com/APN-Pucky/smpl/actions/workflows/stable.yml/badge.svg
[a s link]: https://github.com/APN-Pucky/smpl/actions/workflows/stable.yml
[a t link]: https://github.com/APN-Pucky/smpl/actions/workflows/unstable.yml
[a t image]: https://github.com/APN-Pucky/smpl/actions/workflows/unstable.yml/badge.svg

[cc s q i]: https://app.codacy.com/project/badge/Grade/38630d0063814027bd4d0ffaa73790a2?branch=stable
[cc s q l]: https://www.codacy.com/gh/APN-Pucky/smpl/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=APN-Pucky/smpl&amp;utm_campaign=Badge_Grade?branch=stable
[cc s c i]: https://app.codacy.com/project/badge/Coverage/38630d0063814027bd4d0ffaa73790a2?branch=stable
[cc s c l]: https://www.codacy.com/gh/APN-Pucky/smpl/dashboard?utm_source=github.com&utm_medium=referral&utm_content=APN-Pucky/smpl&utm_campaign=Badge_Coverage?branch=stable

[cc q i]: https://app.codacy.com/project/badge/Grade/38630d0063814027bd4d0ffaa73790a2
[cc q l]: https://www.codacy.com/gh/APN-Pucky/smpl/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=APN-Pucky/smpl&amp;utm_campaign=Badge_Grade
[cc c i]: https://app.codacy.com/project/badge/Coverage/38630d0063814027bd4d0ffaa73790a2
[cc c l]: https://www.codacy.com/gh/APN-Pucky/smpl/dashboard?utm_source=github.com&utm_medium=referral&utm_content=APN-Pucky/smpl&utm_campaign=Badge_Coverage

[c s i]: https://coveralls.io/repos/github/APN-Pucky/smpl/badge.svg?branch=stable
[c s l]: https://coveralls.io/github/APN-Pucky/smpl?branch=stable
[c t l]: https://coveralls.io/github/APN-Pucky/smpl?branch=master
[c t i]: https://coveralls.io/repos/github/APN-Pucky/smpl/badge.svg?branch=master

[rtd s i]: https://readthedocs.org/projects/smpl/badge/?version=stable
[rtd s l]: https://smpl.readthedocs.io/en/stable/?badge=stable
[rtd t i]: https://readthedocs.org/projects/smpl/badge/?version=latest
[rtd t l]: https://smpl.readthedocs.io/en/latest/?badge=latest
